@@ -311,7 +311,8 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
         logger.error('No data returned for this API call. %s', response.request.__dict__)
         return response_status
 
-    df = pandas.read_json(response.text)
+    df = pandas.read_json(response.text, dtype=False)
+    df.rename(columns={"InstallationID": "InstallationId", "ObjectPropertyID": "ObjectPropertyId"}, inplace=True)
 
     return df
 
