@@ -537,7 +537,7 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
     start_date = data_frame['Timestamp'].min(axis=0, skipna=True)
     end_date = data_frame['Timestamp'].max(axis=0, skipna=True)
 
-    timezones = _timezone_offsets(api_inputs=api_inputs, date_from=start_date.date, date_to=end_date.date,
+    timezones = _timezone_offsets(api_inputs=api_inputs, date_from=start_date.date(), date_to=end_date.date(),
                                   installation_id_list=site_list)
     timezones['dateFrom'] = timezones['dateFrom'].apply(lambda x: pandas.to_datetime(x))
     timezones['dateTo'] = timezones['dateTo'].apply(lambda x: pandas.to_datetime(x))
